=== added file 'drizzled/generator/session.h'
--- drizzled/generator/session.h	1970-01-01 00:00:00 +0000
+++ drizzled/generator/session.h	2010-10-20 05:58:54 +0000
@@ -0,0 +1,71 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_GENERATOR_SESSION_H
+#define DRIZZLED_GENERATOR_SESSION_H
+
+#include "drizzled/pthread_globals.h"
+#include "drizzled/session_list.h"
+
+namespace drizzled {
+namespace generator {
+
+class Session
+{
+  SessionList local_list;
+  SessionList::const_iterator iter;
+
+public:
+
+  Session()
+  {
+    LOCK_thread_count.lock();
+    local_list= getSessionList();
+    iter= local_list.begin();
+  }
+
+  ~Session()
+  {
+    LOCK_thread_count.unlock();
+  }
+
+  operator drizzled::SessionPtr()
+  {
+    while (iter != local_list.end())
+    {
+      if (not (*iter)->isViewable())
+      {
+        iter++;
+        continue;
+      }
+
+      drizzled::SessionPtr ret= *iter;
+      iter++;
+      return ret;
+    }
+
+    return NULL;
+  }
+};
+
+} /* namespace generator */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_GENERATOR_SESSION_H */

=== modified file 'drizzled/identifier/schema.cc'
--- drizzled/identifier/schema.cc	2010-09-23 01:53:13 +0000
+++ drizzled/identifier/schema.cc	2010-10-20 01:42:35 +0000
@@ -27,6 +27,8 @@
 #include "drizzled/current_session.h"
 #include "drizzled/internal/my_sys.h"
 
+#include "drizzled/util/backtrace.h"
+
 #include <algorithm>
 #include <sstream>
 #include <cstdio>
@@ -121,8 +123,19 @@
 
 SchemaIdentifier::SchemaIdentifier(const std::string &db_arg) :
   db(db_arg),
-  db_path("")
+  db_path(""),
+  catalog("LOCAL")
 { 
+#if 0
+  string::size_type lastPos= db.find_first_of('/', 0);
+
+  if (lastPos != std::string::npos) 
+  {
+    catalog= db.substr(0, lastPos);
+    db.erase(0, lastPos + 1);
+  }
+#endif
+
   if (not db_arg.empty())
   {
     drizzled::build_schema_filename(db_path, db);

=== modified file 'drizzled/identifier/schema.h'
--- drizzled/identifier/schema.h	2010-08-05 20:24:49 +0000
+++ drizzled/identifier/schema.h	2010-10-20 01:42:35 +0000
@@ -49,12 +49,13 @@
 
 namespace drizzled {
 
-static std::string catalog("");
+static std::string catalog("local");
 
 class SchemaIdentifier
 {
   std::string db;
   std::string db_path;
+  std::string catalog;
 
 
   // @note this should be changed to protected once Session contains an
@@ -92,6 +93,8 @@
                                   SchemaIdentifier &identifier)
   {
     output << "SchemaIdentifier:(";
+    output <<  identifier.catalog;
+    output << ", ";
     output <<  identifier.db;
     output << ", ";
     output << identifier.getPath();

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-10-18 17:22:28 +0000
+++ drizzled/include.am	2010-10-20 06:00:07 +0000
@@ -182,6 +182,7 @@
 			      drizzled/generator/functions.h \
 			      drizzled/generator/event_observers.h \
 			      drizzled/generator/schema.h \
+			      drizzled/generator/session.h \
 			      drizzled/generator/table.h \
 			      drizzled/gettext.h \
 			      drizzled/global_charset_info.h \
@@ -415,6 +416,7 @@
 			      drizzled/table/concurrent.h \
 			      drizzled/table/instance.h \
 			      drizzled/table/placeholder.h \
+			      drizzled/table/shell.h \
 			      drizzled/table/temporary.h \
 			      drizzled/temporal.h \
 			      drizzled/temporal_format.h \

=== modified file 'drizzled/lock.cc'
--- drizzled/lock.cc	2010-10-19 04:37:10 +0000
+++ drizzled/lock.cc	2010-10-19 08:17:10 +0000
@@ -731,7 +731,7 @@
 {
   if (table_list->table)
   {
-    remove_table(table_list->table);
+    remove_table(dynamic_cast<table::Concurrent *>(table_list->table));
     broadcast_refresh();
   }
 }

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2010-09-22 07:05:47 +0000
+++ drizzled/plugin/storage_engine.cc	2010-10-20 01:27:24 +0000
@@ -54,6 +54,8 @@
 #include <drizzled/table_proto.h>
 #include <drizzled/plugin/event_observer.h>
 
+#include <drizzled/table/shell.h>
+
 #include <boost/algorithm/string/compare.hpp>
 
 static bool shutdown_has_begun= false; // Once we put in the container for the vector/etc for engines this will go away.
@@ -501,8 +503,8 @@
                                message::Table& table_message)
 {
   int error= 1;
-  Table table;
   TableShare share(identifier);
+  table::Shell table(share);
   message::Table tmp_proto;
 
   if (share.parse_table_proto(session, table_message) || share.open_table_from_share(&session, identifier, "", 0, 0, table))

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-10-19 13:38:53 +0000
+++ drizzled/session.h	2010-10-20 20:26:18 +0000
@@ -1523,7 +1523,7 @@
 
   /* Reopen operations */
   bool reopen_tables(bool get_locks, bool mark_share_as_old);
-  bool reopen_name_locked_table(TableList* table_list, bool link_in);
+  bool reopen_name_locked_table(TableList* table_list);
   bool close_cached_tables(TableList *tables, bool wait_for_refresh, bool wait_for_placeholders);
 
   void wait_for_condition(boost::mutex &mutex, boost::condition_variable_any &cond);

=== modified file 'drizzled/signal_handler.cc'
--- drizzled/signal_handler.cc	2010-10-10 08:28:30 +0000
+++ drizzled/signal_handler.cc	2010-10-20 01:42:35 +0000
@@ -29,12 +29,7 @@
 #include "drizzled/plugin.h"
 #include "drizzled/plugin/scheduler.h"
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-#include <execinfo.h>
-#include <cxxabi.h>
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+#include "drizzled/util/backtrace.h"
 
 using namespace drizzled;
 
@@ -101,7 +96,6 @@
 #endif
 }
 
-#define BACKTRACE_STACK_SIZE 50
 void drizzled_handle_segfault(int sig)
 {
   time_t curr_time;
@@ -151,65 +145,7 @@
                     "Hope that's ok; if not, decrease some variables in the "
                     "equation.\n\n"));
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-  {
-    void *array[BACKTRACE_STACK_SIZE];
-    size_t size;
-    char **strings;
-
-    size= backtrace(array, BACKTRACE_STACK_SIZE);
-    strings= backtrace_symbols(array, size);
-
-    std::cerr << "Number of stack frames obtained: " << size <<  std::endl;
-
-    for (size_t x= 1; x < size; x++) 
-    {
-      size_t sz= 200;
-      char *function= (char *)malloc(sz);
-      char *begin= 0;
-      char *end= 0;
-
-      for (char *j = strings[x]; *j; ++j)
-      {
-        if (*j == '(') {
-          begin = j;
-        }
-        else if (*j == '+') {
-          end = j;
-        }
-      }
-      if (begin && end)
-      {
-        begin++;
-        *end= '\0';
-
-        int status;
-        char *ret = abi::__cxa_demangle(begin, function, &sz, &status);
-        if (ret) 
-        {
-          function= ret;
-        }
-        else
-        {
-          std::strncpy(function, begin, sz);
-          std::strncat(function, "()", sz);
-          function[sz-1] = '\0';
-        }
-        std::cerr << function << std::endl;
-      }
-      else
-      {
-        std::cerr << strings[x] << std::endl;
-      }
-      free(function);
-    }
-
-
-    free (strings);
-  }
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+  drizzled::util::custom_backtrace();
 
   write_core(sig);
 

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2010-10-14 22:22:23 +0000
+++ drizzled/sql_base.cc	2010-10-20 15:22:36 +0000
@@ -70,9 +70,9 @@
   return open_cache;
 }
 
-static void free_cache_entry(Table *entry);
+static void free_cache_entry(table::Concurrent *entry);
 
-void remove_table(Table *arg)
+void remove_table(table::Concurrent *arg)
 {
   TableOpenCacheRange ppp;
   ppp= get_open_cache().equal_range(arg->getShare()->getCacheKey());
@@ -80,7 +80,7 @@
   for (TableOpenCache::const_iterator iter= ppp.first;
          iter != ppp.second; ++iter)
   {
-    Table *found_table= (*iter).second;
+    table::Concurrent *found_table= (*iter).second;
 
     if (found_table == arg)
     {
@@ -91,7 +91,7 @@
   }
 }
 
-static bool add_table(Table *arg)
+static bool add_table(table::Concurrent *arg)
 {
   TableOpenCache &open_cache(get_open_cache());
 
@@ -101,16 +101,16 @@
 }
 
 class UnusedTables {
-  Table *tables;				/* Used by mysql_test */
+  table::Concurrent *tables;				/* Used by mysql_test */
 
-  Table *getTable() const
+  table::Concurrent *getTable() const
   {
     return tables;
   }
 
-  Table *setTable(Table *arg)
+  table::Concurrent *setTable(Table *arg)
   {
-    return tables= arg;
+    return tables= dynamic_cast<table::Concurrent *>(arg);
   }
 
 public:
@@ -128,7 +128,7 @@
       remove_table(getTable());
   }
   
-  void link(Table *table)
+  void link(table::Concurrent *table)
   {
     if (getTable())
     {
@@ -146,7 +146,7 @@
   }
 
 
-  void unlink(Table *table)
+  void unlink(table::Concurrent *table)
   {
     table->unlink();
 
@@ -161,7 +161,7 @@
 
 /* move table first in unused links */
 
-  void relink(Table *table)
+  void relink(table::Concurrent *table)
   {
     if (table != getTable())
     {
@@ -295,7 +295,7 @@
   We need to have a lock on LOCK_open when calling this
 */
 
-void free_cache_entry(Table *table)
+void free_cache_entry(table::Concurrent *table)
 {
   table->intern_close_table();
   if (not table->in_use)
@@ -504,7 +504,7 @@
 bool Session::free_cached_table()
 {
   bool found_old_table= false;
-  Table *table= open_tables;
+  table::Concurrent *table= dynamic_cast<table::Concurrent *>(open_tables);
 
   safe_mutex_assert_owner(LOCK_open.native_handle());
   assert(table->key_read == 0);
@@ -849,16 +849,16 @@
 
   @param  session     Thread context
   @param  find    Table to remove
+
+  @note because we risk the chance of deleting the share, we can't assume that it will exist past, this should be modified once we can use a TableSharePtr here.
 */
 
 void Session::unlink_open_table(Table *find)
 {
-  char key[MAX_DBKEY_LENGTH];
-  uint32_t key_length= find->getShare()->getCacheKeySize();
-  Table *list, **prev;
+  const TableIdentifier::Key find_key(find->getShare()->getCacheKey());
+  Table **prev;
   safe_mutex_assert_owner(LOCK_open.native_handle());
 
-  memcpy(key, &find->getShare()->getCacheKey()[0], key_length);
   /*
     Note that we need to hold LOCK_open while changing the
     open_tables list. Another thread may work on it.
@@ -868,16 +868,15 @@
   */
   for (prev= &open_tables; *prev; )
   {
-    list= *prev;
+    Table *list= *prev;
 
-    if (list->getShare()->getCacheKeySize() == key_length &&
-        not memcmp(&list->getShare()->getCacheKey()[0], key, key_length))
+    if (list->getShare()->getCacheKey() == find_key)
     {
       /* Remove table from open_tables list. */
       *prev= list->getNext();
 
       /* Close table. */
-      remove_table(list);
+      remove_table(dynamic_cast<table::Concurrent *>(list));
     }
     else
     {
@@ -995,30 +994,20 @@
   true  - Error
 */
 
-bool Session::reopen_name_locked_table(TableList* table_list, bool link_in)
+bool Session::reopen_name_locked_table(TableList* table_list)
 {
   Table *table= table_list->table;
   char *table_name= table_list->table_name;
-  Table orig_table;
 
   safe_mutex_assert_owner(LOCK_open.native_handle());
 
-  if (killed || !table)
+  if (killed || not table)
     return true;
 
-  orig_table= *table;
-
   TableIdentifier identifier(table_list->db, table_list->table_name);
   if (open_unireg_entry(this, table, table_name, identifier))
   {
     table->intern_close_table();
-    /*
-      If there was an error during opening of table (for example if it
-      does not exist) '*table' object can be wiped out. To be able
-      properly release name-lock in this case we should restore this
-      object to its original state.
-    */
-    *table= orig_table;
     return true;
   }
 
@@ -1033,20 +1022,6 @@
   table->getMutableShare()->resetVersion();
   table->in_use = this;
 
-  if (link_in)
-  {
-    table->setNext(open_tables);
-    open_tables= table;
-  }
-  else
-  {
-    /*
-      Table object should be already in Session::open_tables list so we just
-      need to set Table::next correctly.
-    */
-    table->setNext(orig_table.getNext());
-  }
-
   table->tablenr= current_tablenr++;
   table->used_fields= 0;
   table->const_table= 0;
@@ -1384,7 +1359,7 @@
       }
       if (table)
       {
-        unused_tables.unlink(table);
+        unused_tables.unlink(dynamic_cast<table::Concurrent *>(table));
         table->in_use= this;
       }
       else
@@ -1424,21 +1399,24 @@
         }
 
         /* make a new table */
-        table= new Table;
-        if (table == NULL)
         {
-          LOCK_open.unlock();
-          return NULL;
-        }
+          table::Concurrent *new_table= new table::Concurrent;
+          table= new_table;
+          if (new_table == NULL)
+          {
+            LOCK_open.unlock();
+            return NULL;
+          }
 
-        error= open_unireg_entry(this, table, alias, identifier);
-        if (error != 0)
-        {
-          delete table;
-          LOCK_open.unlock();
-          return NULL;
+          error= open_unireg_entry(this, new_table, alias, identifier);
+          if (error != 0)
+          {
+            delete new_table;
+            LOCK_open.unlock();
+            return NULL;
+          }
+          (void)add_table(new_table);
         }
-        (void)add_table(table);
       }
 
       LOCK_open.unlock();
@@ -1591,7 +1569,7 @@
     next= table->getNext();
 
     my_error(ER_CANT_REOPEN_TABLE, MYF(0), table->getAlias());
-    remove_table(table);
+    remove_table(dynamic_cast<table::Concurrent *>(table));
     error= 1;
   }
   *prev=0;
@@ -1843,7 +1821,7 @@
       else
       {
         /* We already have a name lock, remove copy */
-        remove_table(table);
+        remove_table(dynamic_cast<table::Concurrent *>(table));
       }
     }
     else
@@ -1930,7 +1908,10 @@
     {
       share->resetVersion();                        // Mark share as old
       if (discover_retry_count++)               // Retry once
-        goto err;
+      {
+        TableShare::release(share);
+        return 1;
+      }
 
       /*
         TODO->
@@ -1952,7 +1933,10 @@
         using the share.
       */
       if (share->getTableCount() != 1)
-        goto err;
+      {
+        TableShare::release(share);
+        return 1;
+      }
       /* Free share and wait until it's released by all threads */
       TableShare::release(share);
 
@@ -1965,15 +1949,12 @@
       return 1;
     }
 
-    goto err;
+    TableShare::release(share);
+
+    return 1;
   }
 
   return 0;
-
-err:
-  TableShare::release(share);
-
-  return 1;
 }
 
 
@@ -3202,7 +3183,7 @@
     /* true if field_name_1 is a member of using_fields */
     bool is_using_column_1;
     if (!(nj_col_1= it_1.get_or_create_column_ref(leaf_1)))
-      goto err;
+      return(result);
     field_name_1= nj_col_1->name();
     is_using_column_1= using_fields &&
       test_if_string_in_list(field_name_1, using_fields);
@@ -3220,7 +3201,7 @@
       Natural_join_column *cur_nj_col_2;
       const char *cur_field_name_2;
       if (!(cur_nj_col_2= it_2.get_or_create_column_ref(leaf_2)))
-        goto err;
+        return(result);
       cur_field_name_2= cur_nj_col_2->name();
 
       /*
@@ -3240,7 +3221,7 @@
             (found && (!using_fields || is_using_column_1)))
         {
           my_error(ER_NON_UNIQ_ERROR, MYF(0), field_name_1, session->where);
-          goto err;
+          return(result);
         }
         nj_col_2= cur_nj_col_2;
         found= true;
@@ -3273,7 +3254,7 @@
       Item_func_eq *eq_cond;
 
       if (!item_1 || !item_2)
-        goto err;                               // out of memory
+        return(result); // out of memory
 
       /*
         In the case of no_wrap_view_item == 0, the created items must be
@@ -3298,10 +3279,10 @@
       */
       if (set_new_item_local_context(session, item_ident_1, nj_col_1->table_ref) ||
           set_new_item_local_context(session, item_ident_2, nj_col_2->table_ref))
-        goto err;
+        return(result);
 
       if (!(eq_cond= new Item_func_eq(item_ident_1, item_ident_2)))
-        goto err;                               /* Out of memory. */
+        return(result);                               /* Out of memory. */
 
       /*
         Add the new equi-join condition to the ON clause. Notice that
@@ -3347,7 +3328,6 @@
   */
   result= false;
 
-err:
   return(result);
 }
 
@@ -3405,7 +3385,9 @@
 
   if (!(non_join_columns= new List<Natural_join_column>) ||
       !(natural_using_join->join_columns= new List<Natural_join_column>))
-    goto err;
+  {
+    return(result);
+  }
 
   /* Append the columns of the first join operand. */
   for (it_1.set(table_ref_1); !it_1.end_of_fields(); it_1.next())
@@ -3444,7 +3426,7 @@
         {
           my_error(ER_BAD_FIELD_ERROR, MYF(0), using_field_name_ptr,
                    session->where);
-          goto err;
+          return(result);
         }
         if (!my_strcasecmp(system_charset_info,
                            common_field->name(), using_field_name_ptr))
@@ -3472,7 +3454,6 @@
 
   result= false;
 
-err:
   return(result);
 }
 
@@ -3558,7 +3539,7 @@
       if (cur_table_ref->getNestedJoin() &&
           store_top_level_join_columns(session, cur_table_ref,
                                        real_left_neighbor, real_right_neighbor))
-        goto err;
+        return(result);
       same_level_right_neighbor= cur_table_ref;
     }
   }
@@ -3590,7 +3571,7 @@
       std::swap(table_ref_1, table_ref_2);
     if (mark_common_columns(session, table_ref_1, table_ref_2,
                             using_fields, &found_using_fields))
-      goto err;
+      return(result);
 
     /*
       Swap the join operands back, so that we pick the columns of the second
@@ -3602,7 +3583,7 @@
     if (store_natural_using_join_columns(session, table_ref, table_ref_1,
                                          table_ref_2, using_fields,
                                          found_using_fields))
-      goto err;
+      return(result);
 
     /*
       Change NATURAL JOIN to JOIN ... ON. We do this for both operands
@@ -3635,7 +3616,6 @@
   }
   result= false; /* All is OK. */
 
-err:
   return(result);
 }
 
@@ -4280,17 +4260,14 @@
     if ((value->save_in_field(rfield, 0) < 0) && !ignore_errors)
     {
       my_message(ER_UNKNOWN_ERROR, ER(ER_UNKNOWN_ERROR), MYF(0));
-      goto err;
+      if (table)
+        table->auto_increment_field_not_null= false;
+
+      return true;
     }
   }
 
   return session->is_error();
-
-err:
-  if (table)
-    table->auto_increment_field_not_null= false;
-
-  return true;
 }
 
 
@@ -4340,16 +4317,15 @@
     if (field == table->next_number_field)
       table->auto_increment_field_not_null= true;
     if (value->save_in_field(field, 0) < 0)
-      goto err;
+    {
+      if (table)
+        table->auto_increment_field_not_null= false;
+
+      return true;
+    }
   }
 
   return(session->is_error());
-
-err:
-  if (table)
-    table->auto_increment_field_not_null= false;
-
-  return true;
 }
 
 
@@ -4399,7 +4375,7 @@
        iter != get_open_cache().end();
        iter++)
   {
-    Table *table= (*iter).second;
+    table::Concurrent *table= (*iter).second;
 
     if (not schema_identifier.getPath().compare(table->getShare()->getSchemaName()))
     {
@@ -4444,11 +4420,11 @@
     for (TableOpenCache::const_iterator iter= ppp.first;
          iter != ppp.second; ++iter)
     {
-      Table *table= (*iter).second;
+      table::Concurrent *table= (*iter).second;
       Session *in_use;
 
       table->getMutableShare()->resetVersion();		/* Free when thread is ready */
-      if (!(in_use=table->in_use))
+      if (not (in_use= table->in_use))
       {
         unused_tables.relink(table);
       }
@@ -4483,7 +4459,9 @@
         }
       }
       else
+      {
         result= result || (flags & RTFC_OWNED_BY_Session_FLAG);
+      }
     }
 
     unused_tables.cullByVersion();

=== modified file 'drizzled/sql_base.h'
--- drizzled/sql_base.h	2010-07-28 00:15:41 +0000
+++ drizzled/sql_base.h	2010-10-19 08:17:10 +0000
@@ -21,6 +21,7 @@
 #define DRIZZLED_SQL_BASE_H
 
 #include <drizzled/table.h>
+#include <drizzled/table/concurrent.h>
 
 namespace drizzled
 {
@@ -32,11 +33,11 @@
 uint32_t cached_open_tables(void);
 uint32_t cached_table_definitions(void);
 
-typedef boost::unordered_multimap< TableIdentifier::Key, Table *> TableOpenCache;
+typedef boost::unordered_multimap< TableIdentifier::Key, table::Concurrent *> TableOpenCache;
 typedef std::pair< TableOpenCache::const_iterator, TableOpenCache::const_iterator > TableOpenCacheRange;
 
 TableOpenCache &get_open_cache();
-void remove_table(Table *arg);
+void remove_table(table::Concurrent *arg);
 
 void kill_drizzle(void);
 

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2010-10-11 21:57:03 +0000
+++ drizzled/sql_insert.cc	2010-10-20 01:27:24 +0000
@@ -32,6 +32,8 @@
 #include "drizzled/transaction_services.h"
 #include "drizzled/plugin/transactional_storage_engine.h"
 
+#include "drizzled/table/shell.h"
+
 namespace drizzled
 {
 
@@ -1461,9 +1463,7 @@
                                       DrizzleLock **lock,
 				      TableIdentifier &identifier)
 {
-  Table tmp_table;		// Used during 'CreateField()'
   TableShare share(message::Table::INTERNAL);
-  Table *table= 0;
   uint32_t select_field_count= items->elements;
   /* Add selected items to field list */
   List_iterator_fast<Item> it(*items);
@@ -1487,58 +1487,60 @@
     return NULL;
   }
 
-  tmp_table.timestamp_field= 0;
-  tmp_table.setShare(&share);
-
-  tmp_table.getMutableShare()->db_create_options= 0;
-  tmp_table.getMutableShare()->blob_ptr_size= portable_sizeof_char_ptr;
-
-  if (not table_proto.engine().name().compare("MyISAM"))
-    tmp_table.getMutableShare()->db_low_byte_first= true;
-  else if (not table_proto.engine().name().compare("MEMORY"))
-    tmp_table.getMutableShare()->db_low_byte_first= true;
-
-  tmp_table.null_row= false;
-  tmp_table.maybe_null= false;
-
-  tmp_table.in_use= session;
-
-  while ((item=it++))
   {
-    CreateField *cr_field;
-    Field *field, *def_field;
-    if (item->type() == Item::FUNC_ITEM)
+    table::Shell tmp_table(share);		// Used during 'CreateField()'
+    tmp_table.timestamp_field= 0;
+
+    tmp_table.getMutableShare()->db_create_options= 0;
+    tmp_table.getMutableShare()->blob_ptr_size= portable_sizeof_char_ptr;
+
+    if (not table_proto.engine().name().compare("MyISAM"))
+      tmp_table.getMutableShare()->db_low_byte_first= true;
+    else if (not table_proto.engine().name().compare("MEMORY"))
+      tmp_table.getMutableShare()->db_low_byte_first= true;
+
+    tmp_table.null_row= false;
+    tmp_table.maybe_null= false;
+
+    tmp_table.in_use= session;
+
+    while ((item=it++))
     {
-      if (item->result_type() != STRING_RESULT)
+      CreateField *cr_field;
+      Field *field, *def_field;
+      if (item->type() == Item::FUNC_ITEM)
       {
-        field= item->tmp_table_field(&tmp_table);
+        if (item->result_type() != STRING_RESULT)
+        {
+          field= item->tmp_table_field(&tmp_table);
+        }
+        else
+        {
+          field= item->tmp_table_field_from_field_type(&tmp_table, 0);
+        }
       }
       else
       {
-        field= item->tmp_table_field_from_field_type(&tmp_table, 0);
-      }
-    }
-    else
-    {
-      field= create_tmp_field(session, &tmp_table, item, item->type(),
-                              (Item ***) 0, &tmp_field, &def_field, false,
-                              false, false, 0);
-    }
-
-    if (!field ||
-	!(cr_field=new CreateField(field,(item->type() == Item::FIELD_ITEM ?
-					   ((Item_field *)item)->field :
-					   (Field*) 0))))
-    {
-      return NULL;
-    }
-
-    if (item->maybe_null)
-    {
-      cr_field->flags &= ~NOT_NULL_FLAG;
-    }
-
-    alter_info->create_list.push_back(cr_field);
+        field= create_tmp_field(session, &tmp_table, item, item->type(),
+                                (Item ***) 0, &tmp_field, &def_field, false,
+                                false, false, 0);
+      }
+
+      if (!field ||
+          !(cr_field=new CreateField(field,(item->type() == Item::FIELD_ITEM ?
+                                            ((Item_field *)item)->field :
+                                            (Field*) 0))))
+      {
+        return NULL;
+      }
+
+      if (item->maybe_null)
+      {
+        cr_field->flags &= ~NOT_NULL_FLAG;
+      }
+
+      alter_info->create_list.push_back(cr_field);
+    }
   }
 
   /*
@@ -1548,6 +1550,7 @@
     creating base table on which name we have exclusive lock. So code below
     should not cause deadlocks or races.
   */
+  Table *table= 0;
   {
     if (not mysql_create_table_no_lock(session,
 				       identifier,
@@ -1572,12 +1575,14 @@
       if (not identifier.isTmp())
       {
         LOCK_open.lock(); /* CREATE TABLE... has found that the table already exists for insert and is adapting to use it */
-        if (session->reopen_name_locked_table(create_table, false))
+        if (session->reopen_name_locked_table(create_table))
         {
           quick_rm_table(*session, identifier);
         }
         else
+        {
           table= create_table->table;
+        }
         LOCK_open.unlock();
       }
       else
@@ -1595,7 +1600,7 @@
         }
       }
     }
-    if (!table)                                   // open failed
+    if (not table)                                   // open failed
       return NULL;
   }
 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2010-10-15 05:30:39 +0000
+++ drizzled/table.cc	2010-10-20 00:09:13 +0000
@@ -1687,7 +1687,6 @@
 }
 
 Table::Table() : 
-  _share(NULL),
   field(NULL),
   cursor(NULL),
   next(NULL),

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2010-10-15 05:30:39 +0000
+++ drizzled/table.h	2010-10-20 00:09:13 +0000
@@ -61,8 +61,6 @@
  */
 class Table 
 {
-  TableShare *_share; /**< Pointer to the shared metadata about the table */
-
   Field **field; /**< Pointer to fields collection */
 public:
 
@@ -370,15 +368,16 @@
   void resetTable(Session *session, TableShare *share, uint32_t db_stat_arg);
 
   /* SHARE methods */
-  virtual const TableShare *getShare() const { assert(_share); return _share; } /* Get rid of this long term */
-  virtual TableShare *getMutableShare() { assert(_share); return _share; } /* Get rid of this long term */
-  bool hasShare() const { return _share ? true : false ; } /* Get rid of this long term */
-  virtual void setShare(TableShare *new_share) { _share= new_share; } /* Get rid of this long term */
-  uint32_t sizeKeys() { return _share->sizeKeys(); }
-  uint32_t sizeFields() { return _share->sizeFields(); }
-  uint32_t getRecordLength() const { return _share->getRecordLength(); }
-  uint32_t sizeBlobFields() { return _share->blob_fields; }
-  uint32_t *getBlobField() { return &_share->blob_field[0]; }
+  virtual const TableShare *getShare() const= 0; /* Get rid of this long term */
+  virtual TableShare *getMutableShare()= 0; /* Get rid of this long term */
+  virtual bool hasShare() const= 0; /* Get rid of this long term */
+  virtual void setShare(TableShare *new_share)= 0; /* Get rid of this long term */
+
+  uint32_t sizeKeys() { return getMutableShare()->sizeKeys(); }
+  uint32_t sizeFields() { return getMutableShare()->sizeFields(); }
+  uint32_t getRecordLength() const { return getShare()->getRecordLength(); }
+  uint32_t sizeBlobFields() { return getMutableShare()->blob_fields; }
+  uint32_t *getBlobField() { return &getMutableShare()->blob_field[0]; }
 
 public:
   virtual bool hasVariableWidth() const

=== modified file 'drizzled/table/concurrent.h'
--- drizzled/table/concurrent.h	2010-10-14 21:35:55 +0000
+++ drizzled/table/concurrent.h	2010-10-20 00:09:13 +0000
@@ -29,6 +29,8 @@
 
 class Concurrent : public Table
 {
+  TableShare *_share; /**< Pointer to the shared metadata about the table */
+
 public:
   Concurrent() :
     Table()
@@ -38,6 +40,11 @@
   ~Concurrent()
   {
   }
+
+  virtual const TableShare *getShare() const { assert(_share); return _share; } /* Get rid of this long term */
+  virtual TableShare *getMutableShare() { assert(_share); return _share; } /* Get rid of this long term */
+  virtual bool hasShare() const { return _share ? true : false ; } /* Get rid of this long term */
+  virtual void setShare(TableShare *new_share) { _share= new_share; } /* Get rid of this long term */
 };
 
 } /* namespace table */

=== modified file 'drizzled/table/instance.h'
--- drizzled/table/instance.h	2010-10-18 02:32:48 +0000
+++ drizzled/table/instance.h	2010-10-20 00:09:13 +0000
@@ -56,6 +56,8 @@
     return &_share;
   }
 
+  bool hasShare() const { return true; }
+
   bool hasVariableWidth() const
   {
     return _has_variable_width;

=== modified file 'drizzled/table/placeholder.h'
--- drizzled/table/placeholder.h	2010-10-15 05:30:39 +0000
+++ drizzled/table/placeholder.h	2010-10-19 08:17:10 +0000
@@ -29,13 +29,13 @@
 namespace table
 {
 
-class Placeholder : public Table
+class Placeholder : public table::Concurrent
 {
   TableShare private_share;
 
 public:
   Placeholder(Session *session, TableIdentifier &identifier) :
-    Table(),
+    table::Concurrent(),
     private_share(identifier, identifier.getKey())
   {
     setShare(&private_share);

=== added file 'drizzled/table/shell.h'
--- drizzled/table/shell.h	1970-01-01 00:00:00 +0000
+++ drizzled/table/shell.h	2010-10-20 01:27:24 +0000
@@ -0,0 +1,54 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_TABLE_SHELL_H
+#define DRIZZLED_TABLE_SHELL_H
+
+namespace drizzled
+{
+
+namespace table
+{
+
+class Shell : public drizzled::Table
+{
+  TableShare &_share; /**< Pointer to the shared metadata about the table */
+
+public:
+  Shell(TableShare &arg) :
+    Table(),
+    _share(arg)
+  {
+  }
+
+  ~Shell()
+  {
+  }
+
+  const TableShare *getShare() const { return &_share; } /* Get rid of this long term */
+  TableShare *getMutableShare() { return &_share; } /* Get rid of this long term */
+  bool hasShare() const { return true; } /* Get rid of this long term */
+  void setShare(TableShare *) { ; } /* Get rid of this long term */
+};
+
+} /* namespace table */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_TABLE_SHELL_H */

=== modified file 'drizzled/table/temporary.h'
--- drizzled/table/temporary.h	2010-10-14 18:32:09 +0000
+++ drizzled/table/temporary.h	2010-10-20 00:09:13 +0000
@@ -29,6 +29,8 @@
 
 class Temporary : public Table
 {
+  TableShare *_share; /**< Pointer to the shared metadata about the table */
+
 public:
   Temporary() :
     Table()
@@ -38,6 +40,11 @@
   ~Temporary()
   {
   }
+
+  virtual const TableShare *getShare() const { assert(_share); return _share; } /* Get rid of this long term */
+  virtual TableShare *getMutableShare() { assert(_share); return _share; } /* Get rid of this long term */
+  virtual bool hasShare() const { return _share ? true : false ; } /* Get rid of this long term */
+  virtual void setShare(TableShare *new_share) { _share= new_share; } /* Get rid of this long term */
 };
 
 } /* namespace table */

=== modified file 'drizzled/table_share.cc'
--- drizzled/table_share.cc	2010-10-15 01:29:47 +0000
+++ drizzled/table_share.cc	2010-10-20 06:00:07 +0000
@@ -44,6 +44,9 @@
 #include "drizzled/internal/my_pthread.h"
 #include "drizzled/plugin/event_observer.h"
 
+#include "drizzled/table.h"
+#include "drizzled/table/shell.h"
+
 #include "drizzled/session.h"
 
 #include "drizzled/charset.h"
@@ -1444,8 +1447,7 @@
 
     // This needs to go, we should be setting the "use" on the field so that
     // it does not reference the share/table.
-    Table temp_table; /* Use this so that BLOB DEFAULT '' works */
-    temp_table.setShare(this);
+    table::Shell temp_table(*this); /* Use this so that BLOB DEFAULT '' works */
     temp_table.in_use= &session;
 
     f->init(&temp_table); /* blob default values need table obj */
@@ -1825,16 +1827,41 @@
   5    Error (see open_table_error: charset unavailable)
   7    Table definition has changed in engine
 */
-
 int TableShare::open_table_from_share(Session *session,
                                       const TableIdentifier &identifier,
                                       const char *alias,
                                       uint32_t db_stat, uint32_t ha_open_flags,
                                       Table &outparam)
 {
+  bool error_reported= false;
+  int ret= open_table_from_share_inner(session, alias, db_stat, ha_open_flags, outparam, error_reported);
+
+  if (not ret)
+    ret= open_table_cursor_inner(session, identifier, alias, db_stat, ha_open_flags, outparam, error_reported);
+
+  if (not ret)
+    return ret;
+
+  if (not error_reported)
+    open_table_error(ret, errno, 0);
+
+  delete outparam.cursor;
+  outparam.cursor= 0;				// For easier error checking
+  outparam.db_stat= 0;
+  outparam.getMemRoot()->free_root(MYF(0));       // Safe to call on zeroed root
+  free((char*) outparam.alias);
+
+  return ret;
+}
+
+int TableShare::open_table_from_share_inner(Session *session,
+                                            const char *alias,
+                                            uint32_t db_stat, uint32_t ,
+                                            Table &outparam,
+                                            bool &)
+{
   int local_error;
   uint32_t records;
-  bool error_reported= false;
   unsigned char *record= NULL;
   Field **field_ptr;
 
@@ -1845,11 +1872,11 @@
   outparam.resetTable(session, this, db_stat);
 
   if (not (outparam.alias= strdup(alias)))
-    goto err;
+    return local_error;
 
   /* Allocate Cursor */
   if (not (outparam.cursor= db_type()->getCursor(*this)))
-    goto err;
+    return local_error;
 
   local_error= 4;
   records= 0;
@@ -1859,7 +1886,7 @@
   records++;
 
   if (!(record= (unsigned char*) outparam.alloc_root(rec_buff_length * records)))
-    goto err;
+    return local_error;
 
   if (records == 0)
   {
@@ -1895,7 +1922,7 @@
 
   if (!(field_ptr = (Field **) outparam.alloc_root( (uint32_t) ((fields+1)* sizeof(Field*)))))
   {
-    goto err;
+    return local_error;
   }
 
   outparam.setFields(field_ptr);
@@ -1908,7 +1935,7 @@
   for (uint32_t i= 0 ; i < fields; i++, field_ptr++)
   {
     if (!((*field_ptr)= field[i]->clone(outparam.getMemRoot(), &outparam)))
-      goto err;
+      return local_error;
   }
   (*field_ptr)= 0;                              // End marker
 
@@ -1927,7 +1954,7 @@
     uint32_t n_length;
     n_length= keys*sizeof(KeyInfo) + key_parts*sizeof(KeyPartInfo);
     if (!(local_key_info= (KeyInfo*) outparam.alloc_root(n_length)))
-      goto err;
+      return local_error;
     outparam.key_info= local_key_info;
     key_part= (reinterpret_cast<KeyPartInfo*> (local_key_info+keys));
 
@@ -1971,8 +1998,18 @@
   outparam.tmp_set.resize(fields);
   outparam.default_column_bitmaps();
 
+  return 0;
+}
+
+int TableShare::open_table_cursor_inner(Session *,
+                                        const TableIdentifier &identifier,
+                                        const char *,
+                                        uint32_t db_stat, uint32_t ha_open_flags,
+                                        Table &outparam,
+                                        bool &error_reported)
+{
   /* The table struct is now initialized;  Open the table */
-  local_error= 2;
+  int local_error= 2;
   if (db_stat)
   {
     assert(!(db_stat & HA_WAIT_IF_LOCKED));
@@ -2007,23 +2044,11 @@
           local_error= 7;
         break;
       }
-      goto err;
+      return local_error;
     }
   }
 
   return 0;
-
-err:
-  if (!error_reported)
-    open_table_error(local_error, errno, 0);
-
-  delete outparam.cursor;
-  outparam.cursor= 0;				// For easier error checking
-  outparam.db_stat= 0;
-  outparam.getMemRoot()->free_root(MYF(0));       // Safe to call on zeroed root
-  free((char*) outparam.alias);
-
-  return (local_error);
 }
 
 /* error message when opening a form cursor */

=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-10-12 02:56:36 +0000
+++ drizzled/table_share.h	2010-10-20 04:35:44 +0000
@@ -198,18 +198,7 @@
 public:
   bool doesKeyNameExist(const char *name_arg, uint32_t name_length, uint32_t &position) const
   {
-    std::string arg(name_arg, name_length);
-    std::transform(arg.begin(), arg.end(),
-                   arg.begin(), ::toupper);
-
-    std::vector<std::string>::const_iterator iter= std::find(_keynames.begin(), _keynames.end(), arg);
-
-    if (iter == _keynames.end())
-      return false;
-
-    position= iter -  _keynames.begin();
-
-    return true;
+    return doesKeyNameExist(std::string(name_arg, name_length), position);
   }
 
   bool doesKeyNameExist(std::string arg, uint32_t &position) const
@@ -690,6 +679,19 @@
                             const char *alias,
                             uint32_t db_stat, uint32_t ha_open_flags,
                             Table &outparam);
+private:
+  int open_table_from_share_inner(Session *session,
+                                  const char *alias,
+                                  uint32_t db_stat, uint32_t ha_open_flags,
+                                  Table &outparam,
+                                  bool &error_reported);
+  int open_table_cursor_inner(Session *session,
+                              const TableIdentifier &identifier,
+                              const char *alias,
+                              uint32_t db_stat, uint32_t ha_open_flags,
+                              Table &outparam,
+                              bool &error_reported);
+public:
   int parse_table_proto(Session& session, message::Table &table);
 private:
   int inner_parse_table_proto(Session& session, message::Table &table);

=== added file 'drizzled/util/backtrace.cc'
--- drizzled/util/backtrace.cc	1970-01-01 00:00:00 +0000
+++ drizzled/util/backtrace.cc	2010-10-20 20:26:18 +0000
@@ -0,0 +1,104 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#include "config.h"
+#include "drizzled/util/backtrace.h"
+
+#include <string.h>
+#include <stdlib.h>
+#include <iostream>
+
+#ifdef __GNUC__
+#ifdef HAVE_BACKTRACE
+#include <execinfo.h>
+#include <cxxabi.h>
+#endif // HAVE_BACKTRACE
+#endif // __GNUC__
+
+
+namespace drizzled
+{
+namespace util
+{
+
+void custom_backtrace(void)
+{
+#ifdef __GNUC__
+#ifdef HAVE_BACKTRACE
+  void *array[50];
+  size_t size;
+  char **strings;
+
+  size= backtrace(array, 50);
+  strings= backtrace_symbols(array, size);
+
+  std::cerr << "Number of stack frames obtained: " << size <<  std::endl;
+
+  for (size_t x= 1; x < size; x++) 
+  {
+    size_t sz= 200;
+    char *function= (char *)malloc(sz);
+    char *begin= 0;
+    char *end= 0;
+
+    for (char *j = strings[x]; *j; ++j)
+    {
+      if (*j == '(') {
+        begin = j;
+      }
+      else if (*j == '+') {
+        end = j;
+      }
+    }
+    if (begin && end)
+    {
+      begin++;
+      *end= '\0';
+
+      int status;
+      char *ret = abi::__cxa_demangle(begin, function, &sz, &status);
+      if (ret) 
+      {
+        function= ret;
+      }
+      else
+      {
+        strncpy(function, begin, sz);
+        strncat(function, "()", sz);
+        function[sz-1] = '\0';
+      }
+      std::cerr << function << std::endl;
+    }
+    else
+    {
+      std::cerr << strings[x] << std::endl;
+    }
+    free(function);
+  }
+
+
+  free (strings);
+#endif // HAVE_BACKTRACE
+#endif // __GNUC__
+}
+
+} /* namespace util */
+} /* namespace drizzled */

=== added file 'drizzled/util/backtrace.h'
--- drizzled/util/backtrace.h	1970-01-01 00:00:00 +0000
+++ drizzled/util/backtrace.h	2010-10-20 01:42:35 +0000
@@ -0,0 +1,36 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_UTIL_BACKTRACE_H
+#define DRIZZLED_UTIL_BACKTRACE_H
+
+namespace drizzled
+{
+
+namespace util
+{
+
+void custom_backtrace(void);
+
+} /* namespace util */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_UTIL_BACKTRACE_H */
+

=== modified file 'drizzled/util/include.am'
--- drizzled/util/include.am	2010-10-02 21:15:42 +0000
+++ drizzled/util/include.am	2010-10-20 01:42:35 +0000
@@ -15,6 +15,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 nobase_dist_include_HEADERS+= \
+                              drizzled/util/backtrace.h \
                               drizzled/util/convert.h \
                               drizzled/util/functors.h \
 			      drizzled/util/storable.h \
@@ -23,5 +24,7 @@
                               drizzled/util/tokenize.h
 
 noinst_LTLIBRARIES+= drizzled/util/libutil.la
-drizzled_util_libutil_la_SOURCES= drizzled/util/convert.cc
+drizzled_util_libutil_la_SOURCES= \
+                                  drizzled/util/backtrace.cc \
+                                  drizzled/util/convert.cc
 

=== modified file 'plugin/information_schema_dictionary/tests/r/tables.result'
--- plugin/information_schema_dictionary/tests/r/tables.result	2010-10-15 20:54:21 +0000
+++ plugin/information_schema_dictionary/tests/r/tables.result	2010-10-20 01:42:35 +0000
@@ -6,71 +6,71 @@
 	test				
 select * from INFORMATION_SCHEMA.TABLES;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 use information_schema;
 show schemas;
 Database
@@ -80,71 +80,71 @@
 test
 select * from INFORMATION_SCHEMA.TABLES;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_CATALOG=NULL;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA=NULL;
@@ -155,93 +155,93 @@
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
 select * from INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="information_schema" AND TABLE_TYPE="VIEW";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 select * from INFORMATION_SCHEMA.TABLES ORDER BY TABLE_SCHEMA, TABLE_NAME;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_CMP	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
-	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
-	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	INNODB_TRX	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	PROCESSLIST	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
-	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
-	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMPMEM_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_CMP_RESET	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_TRX	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	PROCESSLIST	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMA_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_DEFINITION_CACHE	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_SQL_DEFINITION	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_DOMAIN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	CONSTRAINT_TABLE_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	KEY_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_COLUMN_USAGE	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEW_TABLE_USAGE	VIEW
 create schema a;
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
@@ -262,75 +262,75 @@
 ds
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
+LOCAL	a	a	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "a%";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
-	a	aa	BASE
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "%a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	INFORMATION_SCHEMA	SCHEMATA	VIEW
-	a	a	BASE
-	a	aa	BASE
+LOCAL	INFORMATION_SCHEMA	SCHEMATA	VIEW
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME like "%s";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	DATA_DICTIONARY	CHARACTER_SETS	VIEW
-	DATA_DICTIONARY	COLLATIONS	VIEW
-	DATA_DICTIONARY	COLUMNS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
-	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
-	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
-	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
-	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
-	DATA_DICTIONARY	INDEXES	VIEW
-	DATA_DICTIONARY	INDEX_PARTS	VIEW
-	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
-	DATA_DICTIONARY	INNODB_LOCKS	VIEW
-	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
-	DATA_DICTIONARY	INNODB_STATUS	VIEW
-	DATA_DICTIONARY	MODULES	VIEW
-	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
-	DATA_DICTIONARY	PLUGINS	VIEW
-	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
-	DATA_DICTIONARY	SCHEMAS	VIEW
-	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
-	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
-	DATA_DICTIONARY	SESSION_STATUS	VIEW
-	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
-	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
-	DATA_DICTIONARY	SHOW_INDEXES	VIEW
-	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
-	DATA_DICTIONARY	SHOW_TABLES	VIEW
-	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
-	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
-	DATA_DICTIONARY	TABLES	VIEW
-	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
-	DATA_DICTIONARY	USER_LOCKS	VIEW
-	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	COLUMNS	VIEW
-	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	DOMAINS	VIEW
-	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	PARAMETERS	VIEW
-	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	ROUTINES	VIEW
-	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
-	INFORMATION_SCHEMA	TABLES	VIEW
-	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
-	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
-	INFORMATION_SCHEMA	VIEWS	VIEW
-	a	ds	BASE
+LOCAL	DATA_DICTIONARY	CHARACTER_SETS	VIEW
+LOCAL	DATA_DICTIONARY	COLLATIONS	VIEW
+LOCAL	DATA_DICTIONARY	COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	CUMULATIVE_USER_STATS	VIEW
+LOCAL	DATA_DICTIONARY	CURRENT_SQL_COMMANDS	VIEW
+LOCAL	DATA_DICTIONARY	DRIZZLE_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	FOREIGN_KEYS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	GLOBAL_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	INDEX_PARTS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_INTERNAL_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCKS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_LOCK_WAITS	VIEW
+LOCAL	DATA_DICTIONARY	INNODB_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	MODULES	VIEW
+LOCAL	DATA_DICTIONARY	MYSQL_PROTOCOL_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	PLUGINS	VIEW
+LOCAL	DATA_DICTIONARY	REPLICATION_STREAMS	VIEW
+LOCAL	DATA_DICTIONARY	SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SCOREBOARD_STATISTICS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATEMENTS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SESSION_VARIABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_COLUMNS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_INDEXES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_SCHEMAS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TABLE_STATUS	VIEW
+LOCAL	DATA_DICTIONARY	SHOW_TEMPORARY_TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLES	VIEW
+LOCAL	DATA_DICTIONARY	TABLE_CONSTRAINTS	VIEW
+LOCAL	DATA_DICTIONARY	USER_LOCKS	VIEW
+LOCAL	INFORMATION_SCHEMA	CHECK_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	COLUMN_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAINS	VIEW
+LOCAL	INFORMATION_SCHEMA	DOMAIN_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	PARAMETERS	VIEW
+LOCAL	INFORMATION_SCHEMA	REFERENTIAL_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINES	VIEW
+LOCAL	INFORMATION_SCHEMA	ROUTINE_COLUMNS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLES	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_CONSTRAINTS	VIEW
+LOCAL	INFORMATION_SCHEMA	TABLE_PRIVILEGES	VIEW
+LOCAL	INFORMATION_SCHEMA	VIEWS	VIEW
+LOCAL	a	ds	BASE
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a" ORDER BY TABLE_NAME;
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE
-	a	a	BASE
-	a	aa	BASE
-	a	b	BASE
-	a	c	BASE
-	a	d	BASE
-	a	ds	BASE
+LOCAL	a	a	BASE
+LOCAL	a	aa	BASE
+LOCAL	a	b	BASE
+LOCAL	a	c	BASE
+LOCAL	a	d	BASE
+LOCAL	a	ds	BASE
 drop schema a;
 SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="a";
 TABLE_CATALOG	TABLE_SCHEMA	TABLE_NAME	TABLE_TYPE

=== modified file 'plugin/session_dictionary/processlist.cc'
--- plugin/session_dictionary/processlist.cc	2010-09-19 22:18:23 +0000
+++ plugin/session_dictionary/processlist.cc	2010-10-20 05:58:54 +0000
@@ -52,90 +52,75 @@
   plugin::TableFunction::Generator(arg)
 {
   now= time(NULL);
-
-  LOCK_thread_count.lock();
-  it= getSessionList().begin();
 }
 
 ProcesslistTool::Generator::~Generator()
 {
-  LOCK_thread_count.unlock();
 }
 
 bool ProcesslistTool::Generator::populate()
 {
-  const char *val;
-
-
-  while (it != getSessionList().end())
-  {
-    if ((*it)->isViewable())
-    {
-      break;
-    }
-    ++it;
-  }
-
-  if (it == getSessionList().end())
-    return false;
-
-  Session *tmp= *it;
-  const SecurityContext *tmp_sctx= &tmp->getSecurityContext();
-
-
-  /* ID */
-  push((int64_t) tmp->thread_id);
-
-
-  /* USER */
-  if (not tmp_sctx->getUser().empty())
-    push(tmp_sctx->getUser());
-  else 
-    push(_("no user"));
-
-  /* HOST */
-  push(tmp_sctx->getIp());
-
-  /* DB */
-  if (! tmp->db.empty())
-  {
-    push(tmp->db);
-  }
-  else
-  {
-    push();
-  }
-
-  /* COMMAND */
-  if ((val= const_cast<char *>(tmp->killed == Session::KILL_CONNECTION ? "Killed" : 0)))
-  {
-    push(val);
-  }
-  else
-  {
-    push(command_name[tmp->command].str, command_name[tmp->command].length);
-  }
-
-  /* DRIZZLE_TIME */
-  push(static_cast<uint64_t>(tmp->start_time ?  now - tmp->start_time : 0));
-
-  /* STATE */
-  val= (char*) (tmp->client->isWriting() ?
-                "Writing to net" :
-                tmp->client->isReading() ?
-                (tmp->command == COM_SLEEP ?
-                 NULL : "Reading from net") :
-                tmp->get_proc_info() ? tmp->get_proc_info() :
-                tmp->getThreadVar() &&
-                tmp->getThreadVar()->current_cond ?
-                "Waiting on cond" : NULL);
-  val ? push(val) : push();
-
-  /* INFO */
-  size_t length= strlen(tmp->process_list_info);
-  length ?  push(tmp->process_list_info, length) : push();
-
-  it++;
-
-  return true;
+  drizzled::SessionPtr tmp;
+
+  while ((tmp= session_generator))
+  {
+    const SecurityContext *tmp_sctx= &tmp->getSecurityContext();
+    const char *val;
+
+    /* ID */
+    push((int64_t) tmp->thread_id);
+
+
+    /* USER */
+    if (not tmp_sctx->getUser().empty())
+      push(tmp_sctx->getUser());
+    else 
+      push(_("no user"));
+
+    /* HOST */
+    push(tmp_sctx->getIp());
+
+    /* DB */
+    if (! tmp->db.empty())
+    {
+      push(tmp->db);
+    }
+    else
+    {
+      push();
+    }
+
+    /* COMMAND */
+    if ((val= const_cast<char *>(tmp->killed == Session::KILL_CONNECTION ? "Killed" : 0)))
+    {
+      push(val);
+    }
+    else
+    {
+      push(command_name[tmp->command].str, command_name[tmp->command].length);
+    }
+
+    /* DRIZZLE_TIME */
+    push(static_cast<uint64_t>(tmp->start_time ?  now - tmp->start_time : 0));
+
+    /* STATE */
+    val= (char*) (tmp->client->isWriting() ?
+                  "Writing to net" :
+                  tmp->client->isReading() ?
+                  (tmp->command == COM_SLEEP ?
+                   NULL : "Reading from net") :
+                  tmp->get_proc_info() ? tmp->get_proc_info() :
+                  tmp->getThreadVar() &&
+                  tmp->getThreadVar()->current_cond ?
+                  "Waiting on cond" : NULL);
+    val ? push(val) : push();
+
+    /* INFO */
+    size_t length= strlen(tmp->process_list_info);
+    length ?  push(tmp->process_list_info, length) : push();
+
+    return true;
+  }
+
+  return false;
 }

=== modified file 'plugin/session_dictionary/processlist.h'
--- plugin/session_dictionary/processlist.h	2010-03-04 16:54:08 +0000
+++ plugin/session_dictionary/processlist.h	2010-10-20 05:58:54 +0000
@@ -19,7 +19,7 @@
  */
 
 #include "drizzled/session.h"
-#include "drizzled/session_list.h"
+#include "drizzled/generator/session.h"
 
 #ifndef PLUGIN_SESSION_DICTIONARY_PROCESSLIST_H
 #define PLUGIN_SESSION_DICTIONARY_PROCESSLIST_H
@@ -33,7 +33,7 @@
   class Generator : public drizzled::plugin::TableFunction::Generator 
   {
     time_t now;
-    drizzled::SessionList::iterator it;
+    drizzled::generator::Session session_generator;
 
   public:
     Generator(drizzled::Field **arg);

